# eis_payments
This service directly communicates with the various Payment Service Providers (PSPs)
  in order to charge or refund customers. This service will automatically connect to the PSP linked
  in your admin configuration; meaning if you configured Stripe, it will automatically create a payment
  on Stripe when you create it in Emil.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0
- Package version: 1.10.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://www.emil.de](https://www.emil.de)

## Requirements.

Python >=3.6

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install eis.payment
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import eis.payment
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import eis.payment
```

## Getting Started

The environment variables must be set in order to properly use this SDK.

```shell 
export EMIL_USERNAME=XXXXXXX
export EMIL_PASSWORD=XXXXXXX
```

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
import time
import eis.payment
from pprint import pprint
from eis.payment.api import bank_accounts_api
from eis.payment.model.create_bank_account_request_dto import CreateBankAccountRequestDto
from eis.payment.model.create_bank_account_response_class import CreateBankAccountResponseClass
from eis.payment.model.get_bank_account_response_class import GetBankAccountResponseClass
from eis.payment.model.list_bank_accounts_response_class import ListBankAccountsResponseClass
from eis.payment.model.set_primary_bank_account_request_dto_rest import SetPrimaryBankAccountRequestDtoRest
from eis.payment.model.update_bank_account_request_dto_rest import UpdateBankAccountRequestDtoRest
from eis.payment.model.update_bank_account_response_class import UpdateBankAccountResponseClass
# Defining the host is optional and defaults to https://apiv2.emil.de
# See configuration.py for a list of all supported configuration parameters.
configuration = eis.payment.Configuration(
    host = "https://apiv2.emil.de"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Bearer is automatically handled with exported environment variables. However, you
# can manuallay configure Bearer authorization (JWT): bearer
configuration = eis.payment.Configuration(
    access_token = 'YOUR_BEARER_TOKEN'
)

# After manual token becomes invalid, the SDK will default to re-login automatically
# with environment variable credentials.


# Enter a context with an instance of the API client
with eis.payment.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = bank_accounts_api.BankAccountsApi(api_client)
    create_bank_account_request_dto = CreateBankAccountRequestDto(
        account_code="acc_X0LTUarBwAxUMZRb",
        partner_code="pr_ecTjOhuwgcXChufCG0tvv",
        iban="DE89370400440532013000",
        account_holder="Emil Mustermann",
    ) # CreateBankAccountRequestDto | 
    authorization = "Authorization_example" # str | Bearer Token (optional)

    try:
        # Create the bank account
        api_response = api_instance.create_bank_account(create_bank_account_request_dto, authorization=authorization)
        pprint(api_response)
    except eis.payment.ApiException as e:
        print("Exception when calling BankAccountsApi->create_bank_account: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://apiv2.emil.de*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*BankAccountsApi* | [**create_bank_account**](docs/BankAccountsApi.md#create_bank_account) | **POST** /paymentservice/v1/bank-accounts | Create the bank account
*BankAccountsApi* | [**delete_bank_account**](docs/BankAccountsApi.md#delete_bank_account) | **DELETE** /paymentservice/v1/bank-accounts/{code} | Delete the bank account
*BankAccountsApi* | [**get_bank_account**](docs/BankAccountsApi.md#get_bank_account) | **GET** /paymentservice/v1/bank-accounts/{code} | Retrieve the bank account
*BankAccountsApi* | [**list_bank_accounts**](docs/BankAccountsApi.md#list_bank_accounts) | **GET** /paymentservice/v1/bank-accounts | List bank accounts
*BankAccountsApi* | [**set_primary_bank_account**](docs/BankAccountsApi.md#set_primary_bank_account) | **POST** /paymentservice/v1/bank-accounts/{code}/primary | Set primary bank account
*BankAccountsApi* | [**update_bank_account**](docs/BankAccountsApi.md#update_bank_account) | **PUT** /paymentservice/v1/bank-accounts/{code} | Update the bank account
*BankOrdersApi* | [**create_bank_order**](docs/BankOrdersApi.md#create_bank_order) | **POST** /paymentservice/v1/bank-orders | Create the bank order
*BankOrdersApi* | [**delete_bank_order**](docs/BankOrdersApi.md#delete_bank_order) | **DELETE** /paymentservice/v1/bank-orders/{code} | Delete the bank order
*BankOrdersApi* | [**get_bank_order**](docs/BankOrdersApi.md#get_bank_order) | **GET** /paymentservice/v1/bank-orders/{code} | Retrieve the bank order
*BankOrdersApi* | [**list_bank_orders**](docs/BankOrdersApi.md#list_bank_orders) | **GET** /paymentservice/v1/bank-orders | List bank orders
*BankOrdersApi* | [**update_bank_order**](docs/BankOrdersApi.md#update_bank_order) | **PUT** /paymentservice/v1/bank-orders/{code} | Update the bank order
*BankTransactionApi* | [**generate_invoice_match_suggestion**](docs/BankTransactionApi.md#generate_invoice_match_suggestion) | **POST** /paymentservice/v1/tenant/bank-transactions/{code}/generate-invoice-match-suggestion | Invoice Match Suggestion
*BankTransactionApi* | [**get_bank_transaction**](docs/BankTransactionApi.md#get_bank_transaction) | **GET** /paymentservice/v1/tenant/bank-transactions/{code} | Retrieve the bank transaction
*BankTransactionApi* | [**import_bank_transactions**](docs/BankTransactionApi.md#import_bank_transactions) | **POST** /paymentservice/v1/tenant/bank-transactions/import | Create the bank transactions
*BankTransactionApi* | [**link_bank_transaction**](docs/BankTransactionApi.md#link_bank_transaction) | **POST** /paymentservice/v1/tenant/bank-transactions/{code}/link | Link bank transaction
*BankTransactionApi* | [**list_bank_transactions**](docs/BankTransactionApi.md#list_bank_transactions) | **GET** /paymentservice/v1/tenant/bank-transactions | List bank transactions
*BankTransactionApi* | [**unlink_bank_transaction**](docs/BankTransactionApi.md#unlink_bank_transaction) | **POST** /paymentservice/v1/tenant/bank-transactions/{code}/unlink | Unlink bank transaction
*CreditAllocationApi* | [**create_allocate_credit**](docs/CreditAllocationApi.md#create_allocate_credit) | **POST** /paymentservice/v1/credit-allocations | Create the credit allocation
*CreditAllocationApi* | [**get_credit_allocation**](docs/CreditAllocationApi.md#get_credit_allocation) | **GET** /paymentservice/v1/credit-allocations/{code} | Retrieve the credit allocation entry
*CreditAllocationApi* | [**list_credit_allocations**](docs/CreditAllocationApi.md#list_credit_allocations) | **GET** /paymentservice/v1/credit-allocations | List credit allocations
*ExceedingCreditsApi* | [**get_exceeding_credit**](docs/ExceedingCreditsApi.md#get_exceeding_credit) | **GET** /paymentservice/v1/exceeding-credits/{code} | Retrieve the exceeding credit
*ExceedingCreditsApi* | [**list_exceeding_credits**](docs/ExceedingCreditsApi.md#list_exceeding_credits) | **GET** /paymentservice/v1/exceeding-credits | List exceeding credits
*HealthCheckApi* | [**check**](docs/HealthCheckApi.md#check) | **GET** /paymentservice/health | Health Check
*PaymentMethodsApi* | [**create_payment_method**](docs/PaymentMethodsApi.md#create_payment_method) | **POST** /paymentservice/v1/payment-methods | Create the payment method
*PaymentMethodsApi* | [**get_payment_method**](docs/PaymentMethodsApi.md#get_payment_method) | **GET** /paymentservice/v1/payment-methods/{code} | Retrieve the payment method
*PaymentMethodsApi* | [**list_payment_methods**](docs/PaymentMethodsApi.md#list_payment_methods) | **GET** /paymentservice/v1/payment-methods | List payment methods
*PaymentRemindersApi* | [**create_payment_reminder**](docs/PaymentRemindersApi.md#create_payment_reminder) | **POST** /paymentservice/v1/payment-reminders | Create the payment reminder
*PaymentRemindersApi* | [**deactivate_payment_reminder**](docs/PaymentRemindersApi.md#deactivate_payment_reminder) | **POST** /paymentservice/v1/payment-reminders/{code}/deactivate | Deactivate payment reminder
*PaymentRemindersApi* | [**get_payment_reminder**](docs/PaymentRemindersApi.md#get_payment_reminder) | **GET** /paymentservice/v1/payment-reminders/{code} | Retrieve the payment reminder
*PaymentRemindersApi* | [**list_payment_reminders**](docs/PaymentRemindersApi.md#list_payment_reminders) | **GET** /paymentservice/v1/payment-reminders | List payment reminders
*PaymentSetupApi* | [**complete_payment_setup**](docs/PaymentSetupApi.md#complete_payment_setup) | **POST** /paymentservice/v1/payment-setup/complete | Complete a payment setup
*PaymentSetupApi* | [**initiate_payment_setup**](docs/PaymentSetupApi.md#initiate_payment_setup) | **POST** /paymentservice/v1/payment-setup/initiate | Initiate a payment setup
*PaymentsApi* | [**create_payment**](docs/PaymentsApi.md#create_payment) | **POST** /paymentservice/v1/payments | Create the payment
*PaymentsApi* | [**create_payment_order**](docs/PaymentsApi.md#create_payment_order) | **POST** /paymentservice/v1/payments/order | Create the payment
*PaymentsApi* | [**get_payment**](docs/PaymentsApi.md#get_payment) | **GET** /paymentservice/v1/payments/{code} | Retrieve the payment
*PaymentsApi* | [**list_payments**](docs/PaymentsApi.md#list_payments) | **GET** /paymentservice/v1/payments | List payments
*PolicyPaymentMethodsApi* | [**activate_policy_payment_method**](docs/PolicyPaymentMethodsApi.md#activate_policy_payment_method) | **POST** /paymentservice/v1/policy-payment-methods/activate/{code} | Activate the policy payment method
*PolicyPaymentMethodsApi* | [**create_policy_payment_method**](docs/PolicyPaymentMethodsApi.md#create_policy_payment_method) | **POST** /paymentservice/v1/policy-payment-methods | Create the policy payment method
*PolicyPaymentMethodsApi* | [**list_policy_payment_methods**](docs/PolicyPaymentMethodsApi.md#list_policy_payment_methods) | **GET** /paymentservice/v1/policy-payment-methods | Retrieve the policy payment methods
*RefundsApi* | [**create_refund**](docs/RefundsApi.md#create_refund) | **POST** /paymentservice/v1/refunds | Create the refund
*RefundsApi* | [**get_refund**](docs/RefundsApi.md#get_refund) | **GET** /paymentservice/v1/refunds/{code} | Retrieve the refund
*RefundsApi* | [**list_refunds**](docs/RefundsApi.md#list_refunds) | **GET** /paymentservice/v1/refunds | List refunds
*TenantBankAccountApi* | [**create_tenant_bank_account**](docs/TenantBankAccountApi.md#create_tenant_bank_account) | **POST** /paymentservice/v1/tenant/bank-accounts | Create the tenant bank account
*TenantBankAccountApi* | [**delete_tenant_bank_account**](docs/TenantBankAccountApi.md#delete_tenant_bank_account) | **DELETE** /paymentservice/v1/tenant/bank-accounts/{code} | Delete the tenant bank account
*TenantBankAccountApi* | [**get_tenant_bank_account**](docs/TenantBankAccountApi.md#get_tenant_bank_account) | **GET** /paymentservice/v1/tenant/bank-accounts/{code} | Retrieve the tenant bank account
*TenantBankAccountApi* | [**list_tenant_bank_accounts**](docs/TenantBankAccountApi.md#list_tenant_bank_accounts) | **GET** /paymentservice/v1/tenant/bank-accounts | List tenant bank accounts
*TenantBankAccountApi* | [**update_tenant_bank_account**](docs/TenantBankAccountApi.md#update_tenant_bank_account) | **PUT** /paymentservice/v1/tenant/bank-accounts/{code} | Update the tenant bank account
*WebhooksApi* | [**post_webhook**](docs/WebhooksApi.md#post_webhook) | **POST** /paymentservice/v1/webhooks/{pspType}/{tenantSlug}/{productSlug} | Handle the webhook from PSP


## Documentation For Models

 - [ActivatePolicyPaymentMethodRequestDto](docs/ActivatePolicyPaymentMethodRequestDto.md)
 - [BankAccountClass](docs/BankAccountClass.md)
 - [BankAccountClassWithoutExpandProperties](docs/BankAccountClassWithoutExpandProperties.md)
 - [BankOrderClass](docs/BankOrderClass.md)
 - [BankOrderEntity](docs/BankOrderEntity.md)
 - [BankOrderXmlFileClass](docs/BankOrderXmlFileClass.md)
 - [BankOrderXmlFileEntity](docs/BankOrderXmlFileEntity.md)
 - [BankTransactionClass](docs/BankTransactionClass.md)
 - [BankTransactionClassWithoutExpandProperties](docs/BankTransactionClassWithoutExpandProperties.md)
 - [BankTransactionEntity](docs/BankTransactionEntity.md)
 - [BankTransactionInvoiceClass](docs/BankTransactionInvoiceClass.md)
 - [BankTransactionInvoiceEntity](docs/BankTransactionInvoiceEntity.md)
 - [BankTransferDto](docs/BankTransferDto.md)
 - [BillingAddressDto](docs/BillingAddressDto.md)
 - [BillingProfileDto](docs/BillingProfileDto.md)
 - [BillingProfileLimitedResponseDto](docs/BillingProfileLimitedResponseDto.md)
 - [CardDetailsDto](docs/CardDetailsDto.md)
 - [CompleteAdyenPaymentSetupRequestDto](docs/CompleteAdyenPaymentSetupRequestDto.md)
 - [CompleteBraintreePaymentSetupRequestDto](docs/CompleteBraintreePaymentSetupRequestDto.md)
 - [CompleteEisPaymentSetupRequestDto](docs/CompleteEisPaymentSetupRequestDto.md)
 - [CompletePaymentSetupRequestDto](docs/CompletePaymentSetupRequestDto.md)
 - [CompletePaymentSetupResponseClass](docs/CompletePaymentSetupResponseClass.md)
 - [CompleteStripePaymentSetupRequestDto](docs/CompleteStripePaymentSetupRequestDto.md)
 - [CreateBankAccountRequestDto](docs/CreateBankAccountRequestDto.md)
 - [CreateBankAccountResponseClass](docs/CreateBankAccountResponseClass.md)
 - [CreateBankOrderRequestDto](docs/CreateBankOrderRequestDto.md)
 - [CreateBankOrderResponseClass](docs/CreateBankOrderResponseClass.md)
 - [CreateCreditAllocationRequestDto](docs/CreateCreditAllocationRequestDto.md)
 - [CreateCreditAllocationResponseClass](docs/CreateCreditAllocationResponseClass.md)
 - [CreatePaymentMethodResponseClass](docs/CreatePaymentMethodResponseClass.md)
 - [CreatePaymentOrderDto](docs/CreatePaymentOrderDto.md)
 - [CreatePaymentOrderRequestDto](docs/CreatePaymentOrderRequestDto.md)
 - [CreatePaymentReminderRequestDto](docs/CreatePaymentReminderRequestDto.md)
 - [CreatePaymentReminderResponseClass](docs/CreatePaymentReminderResponseClass.md)
 - [CreatePaymentRequestDto](docs/CreatePaymentRequestDto.md)
 - [CreatePaymentResponseClass](docs/CreatePaymentResponseClass.md)
 - [CreatePolicyPaymentMethodRequestDto](docs/CreatePolicyPaymentMethodRequestDto.md)
 - [CreatePolicyPaymentMethodResponseClass](docs/CreatePolicyPaymentMethodResponseClass.md)
 - [CreatePspPaymentMethodRequestDto](docs/CreatePspPaymentMethodRequestDto.md)
 - [CreateRefundRequestDto](docs/CreateRefundRequestDto.md)
 - [CreateRefundResponseClass](docs/CreateRefundResponseClass.md)
 - [CreateTenantBankAccountRequestDto](docs/CreateTenantBankAccountRequestDto.md)
 - [CreateTenantBankAccountResponseClass](docs/CreateTenantBankAccountResponseClass.md)
 - [CreditAllocationClass](docs/CreditAllocationClass.md)
 - [CreditAllocationEntity](docs/CreditAllocationEntity.md)
 - [DeactivatePaymentReminderRequestDto](docs/DeactivatePaymentReminderRequestDto.md)
 - [DeactivatePaymentReminderResponseClass](docs/DeactivatePaymentReminderResponseClass.md)
 - [DeactivatedPaymentReminderClass](docs/DeactivatedPaymentReminderClass.md)
 - [EisSepaDebitDto](docs/EisSepaDebitDto.md)
 - [ExceedingCreditClass](docs/ExceedingCreditClass.md)
 - [ExceedingCreditEntity](docs/ExceedingCreditEntity.md)
 - [GenerateInvoiceMatchSuggestionsResponseClass](docs/GenerateInvoiceMatchSuggestionsResponseClass.md)
 - [GetBankAccountResponseClass](docs/GetBankAccountResponseClass.md)
 - [GetBankOrderResponseClass](docs/GetBankOrderResponseClass.md)
 - [GetBankTransactionsResponseClass](docs/GetBankTransactionsResponseClass.md)
 - [GetCreditAllocationResponseClass](docs/GetCreditAllocationResponseClass.md)
 - [GetExceedingCreditResponseClass](docs/GetExceedingCreditResponseClass.md)
 - [GetPaymentMethodResponseClass](docs/GetPaymentMethodResponseClass.md)
 - [GetPaymentReminderResponseClass](docs/GetPaymentReminderResponseClass.md)
 - [GetPaymentResponseClass](docs/GetPaymentResponseClass.md)
 - [GetRefundResponseClass](docs/GetRefundResponseClass.md)
 - [GetTenantBankAccountResponseClass](docs/GetTenantBankAccountResponseClass.md)
 - [ImportBankTransactionsResponseClass](docs/ImportBankTransactionsResponseClass.md)
 - [InitiateAdyenPaymentSetupRequestDto](docs/InitiateAdyenPaymentSetupRequestDto.md)
 - [InitiateAdyenPaymentSetupResponseClass](docs/InitiateAdyenPaymentSetupResponseClass.md)
 - [InitiateBraintreePaymentSetupRequestDto](docs/InitiateBraintreePaymentSetupRequestDto.md)
 - [InitiateBraintreePaymentSetupResponseClass](docs/InitiateBraintreePaymentSetupResponseClass.md)
 - [InitiateEisPaymentSetupRequestDto](docs/InitiateEisPaymentSetupRequestDto.md)
 - [InitiatePaymentSetupRequestDto](docs/InitiatePaymentSetupRequestDto.md)
 - [InitiatePaymentSetupResponseClass](docs/InitiatePaymentSetupResponseClass.md)
 - [InitiateStripePaymentSetupRequestDto](docs/InitiateStripePaymentSetupRequestDto.md)
 - [InitiateStripePaymentSetupResponseClass](docs/InitiateStripePaymentSetupResponseClass.md)
 - [InlineResponse200](docs/InlineResponse200.md)
 - [InlineResponse503](docs/InlineResponse503.md)
 - [InvoiceAllocationDto](docs/InvoiceAllocationDto.md)
 - [InvoiceMatchSuggestionClass](docs/InvoiceMatchSuggestionClass.md)
 - [InvoiceMatchSuggestionEntity](docs/InvoiceMatchSuggestionEntity.md)
 - [LinkBankTransactionRequestDtoRest](docs/LinkBankTransactionRequestDtoRest.md)
 - [LinkBankTransactionsResponseClass](docs/LinkBankTransactionsResponseClass.md)
 - [ListBankAccountsResponseClass](docs/ListBankAccountsResponseClass.md)
 - [ListBankOrdersResponseClass](docs/ListBankOrdersResponseClass.md)
 - [ListBankTransactionsResponseClass](docs/ListBankTransactionsResponseClass.md)
 - [ListCreditAllocationsResponseClass](docs/ListCreditAllocationsResponseClass.md)
 - [ListExceedingCreditsResponseClass](docs/ListExceedingCreditsResponseClass.md)
 - [ListPaymentMethodsResponseClass](docs/ListPaymentMethodsResponseClass.md)
 - [ListPaymentRemindersResponseClass](docs/ListPaymentRemindersResponseClass.md)
 - [ListPaymentsResponseClass](docs/ListPaymentsResponseClass.md)
 - [ListPolicyPaymentMethodsResponseClass](docs/ListPolicyPaymentMethodsResponseClass.md)
 - [ListRefundsResponseClass](docs/ListRefundsResponseClass.md)
 - [ListTenantBankAccountResponseClass](docs/ListTenantBankAccountResponseClass.md)
 - [MandateDto](docs/MandateDto.md)
 - [MandateHashDataDto](docs/MandateHashDataDto.md)
 - [MandateReferenceClass](docs/MandateReferenceClass.md)
 - [PaymentClass](docs/PaymentClass.md)
 - [PaymentClassWithoutExpandProperties](docs/PaymentClassWithoutExpandProperties.md)
 - [PaymentEntity](docs/PaymentEntity.md)
 - [PaymentMethodClass](docs/PaymentMethodClass.md)
 - [PaymentReminderClass](docs/PaymentReminderClass.md)
 - [PolicyPaymentMethodClass](docs/PolicyPaymentMethodClass.md)
 - [PrimaryBankAccountResponseClass](docs/PrimaryBankAccountResponseClass.md)
 - [RefundClass](docs/RefundClass.md)
 - [RefundItemClass](docs/RefundItemClass.md)
 - [SepaDirectDto](docs/SepaDirectDto.md)
 - [SetPrimaryBankAccountRequestDtoRest](docs/SetPrimaryBankAccountRequestDtoRest.md)
 - [SharedTransactionClass](docs/SharedTransactionClass.md)
 - [SuggestionGenerationProgressClass](docs/SuggestionGenerationProgressClass.md)
 - [SuggestionGenerationProgressEntity](docs/SuggestionGenerationProgressEntity.md)
 - [SymphonyProfileLimitedResponseDto](docs/SymphonyProfileLimitedResponseDto.md)
 - [TenantBankAccountClass](docs/TenantBankAccountClass.md)
 - [TenantBankAccountClassWithoutExpandProperties](docs/TenantBankAccountClassWithoutExpandProperties.md)
 - [TenantBankAccountEntity](docs/TenantBankAccountEntity.md)
 - [TransactionEntity](docs/TransactionEntity.md)
 - [UnlinkBankTransactionsResponseClass](docs/UnlinkBankTransactionsResponseClass.md)
 - [UnlinkedBankTransactionResponseClass](docs/UnlinkedBankTransactionResponseClass.md)
 - [UpdateBankAccountRequestDto](docs/UpdateBankAccountRequestDto.md)
 - [UpdateBankAccountRequestDtoRest](docs/UpdateBankAccountRequestDtoRest.md)
 - [UpdateBankAccountResponseClass](docs/UpdateBankAccountResponseClass.md)
 - [UpdateBankOrderRequestDto](docs/UpdateBankOrderRequestDto.md)
 - [UpdateBankOrderResponseClass](docs/UpdateBankOrderResponseClass.md)
 - [UpdateTenantBankAccountResponseClass](docs/UpdateTenantBankAccountResponseClass.md)
 - [UpdateTenantBankAccountRestRequestDto](docs/UpdateTenantBankAccountRestRequestDto.md)
 - [ValidatePSPConfigRequestDto](docs/ValidatePSPConfigRequestDto.md)


## Documentation For Authorization


## bearer

- **Type**: Bearer authentication (JWT)


## Author

kontakt@emil.de


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in eis.payment.apis and eis.payment.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from eis.payment.api.default_api import DefaultApi`
- `from eis.payment.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import eis.payment
from eis.payment.apis import *
from eis.payment.models import *
```

